<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:template match="batch">
<html>
<head>
<title>
Thermo Scientific EASY-nLC batch - <xsl:value-of select="name" />
</title>
</head>
<body>
<h2>Thermo Scientific EASY-nLC batch</h2> 
<hr /> 
<h3>About</h3> 
<table border="0">
<tr>
<td >Owner</td> 
<td>
<xsl:value-of select="owner" /> 
</td>
</tr>
<tr>
<td>Name</td> 
<td>
<xsl:value-of select="name" /> 
</td>
</tr>
<tr>
<td>Description</td> 
<td>
<xsl:value-of select="description" /> 
</td>
</tr>
</table>
<hr /> 

<h3>Autosampler configuration</h3> 
<table border="1">
<xsl:apply-templates select="autosamplerconfiguration" />
<xsl:apply-templates select="plateformat" />
</table>

<xsl:apply-templates select="methods" /> 
<xsl:apply-templates select="samples" /> 
</body>
</html>
</xsl:template>

<!-- template for old-style top-level plateformat node -->
<xsl:template match="plateformat">
	<tr><th>Plate format</th></tr>
	<tr>
	<td>
	<xsl:value-of select="row" />x<xsl:value-of select="column" />
	/
	<xsl:value-of select="producent" />
	</td>
	</tr>
</xsl:template>

<xsl:template match="autosamplerconfiguration">
	<tr><th>Rack position</th><th>Rack type</th><th>Plate format</th></tr>
	<xsl:for-each select="autosamplerrackposition">
		<tr>
		<th>
		<xsl:value-of select="@positionId" />
		</th>
		<td>
		<xsl:value-of select="@typeName" />
		</td>
		<td>
		<xsl:value-of select="plateformat/row" />x<xsl:value-of select="plateformat/column" />
		/
		<xsl:value-of select="plateformat/producent" />
		</td>
		</tr>
	</xsl:for-each>
</xsl:template>



<xsl:template match="methods">
<hr /> 
<h3>Methods</h3> 
<table border="0">
<tr>
<td>Method ID: <xsl:value-of select="methodId" /> </td> 
<td/>
</tr>
<tr>
<ul>
<xsl:apply-templates select="method">
<xsl:sort select="methodId" /> 
</xsl:apply-templates>
</ul>
</tr>
</table>
</xsl:template>
<xsl:template match="method">
<table border="1">
<tr>
<td>Owner</td> 
<td>
<xsl:value-of select="owner" /> 
</td>
</tr>
<tr>
<td>Name</td> 
<td>
<xsl:value-of select="name" /> 
</td>
</tr>
<tr>
<td>Description</td> 
<td>
<xsl:value-of select="description" /> 
</td>
</tr>
<tr>
<td>Sample Pickup Volume</td> 
<td>
<xsl:value-of select="sampleLoadingVolume" /> 
ul 
</td>
</tr>
<tr>
<td>Sample Pickup Flow</td> 
<td>
<xsl:value-of select="sampleLoadingFlow" /> 
ul/min 
</td>
</tr>
<tr>
<td>Sample loading Volume</td> 
<td>
<xsl:value-of select="desaltingVolume" /> 
ul 
</td>
</tr>
<tr>
<td>Sample loading Flow</td> 
<td>
<xsl:value-of select="desaltingFlow" /> 
ul/min 
</td>
</tr>
<tr>
<td>Sample loading Max pressure</td> 
<td>
<xsl:value-of select="desaltingMaxPressure" /> 
Bar 
</td>
</tr>
<xsl:apply-templates select="gradients" /> 
<tr>
<td>Pre-column equilibration Volume</td> 
<td>
<xsl:value-of select="reEquilibrationPreColumnVolume" /> 
ul 
</td>
</tr>
<tr>
<td>Pre-column equilibration Flow</td> 
<td>
<xsl:value-of select="reEquilibrationPreColumnFlow" /> 
ul/min 
</td>
</tr>
<tr>
<td>Pre-column equilibration Max Pressure</td> 
<td>
<xsl:value-of select="reEquilibrationPreColumnMaxPressure" /> 
Bar 
</td>
</tr>
<tr>
<td>Analytical column equilibration Volume</td> 
<td>
<xsl:value-of select="reEquilibrationAnalyticalColumnVolume" /> 
ul 
</td>
</tr>
<tr>
<td>Analytical column equilibration Flow</td> 
<td>
<xsl:value-of select="reEquilibrationAnalyticalColumnFlow" /> 
ul/min 
</td>
</tr>
<tr>
<td>Analytical column equilibration Max Pressure</td> 
<td>
<xsl:value-of select="reEquilibrationAnalyticalColumnMaxPressure" /> 
Bar 
</td>
</tr>
<tr>
<td>Autosampler Flush volume</td> 
<td>
<xsl:value-of select="washFlushVolume" /> 
ul 
</td>
</tr>
<tr>
<td>Autosampler Custom wash</td> 
<td>
<xsl:value-of select="isWashCyclesEnabled" /> 
</td>
</tr>
<xsl:apply-templates select="washcycles" /> 
</table>
</xsl:template>
<xsl:template match="washcycles">
<tr>
<td>washcycles</td> 
<td>
<table border="1"><tr>
<td>Source</td> 
<td>Volume</td> 
<td>Cycles</td> 
</tr>
<xsl:apply-templates select="methodwashcycle">
<xsl:sort select="order" data-type="number"/> 
</xsl:apply-templates>
</table>
</td>
</tr>
</xsl:template>
<xsl:template match="methodwashcycle">
<tr>
<td>
<xsl:value-of select="source" /> 
</td>
<td>
<xsl:value-of select="volume" /> 
</td>
<td>
<xsl:value-of select="cycles" /> 
</td>
</tr>
</xsl:template>
<xsl:template match="gradients">
<tr>
<td>Gradient</td>
<td>
<table border="1">
<tr>
<td>Time</td> 
<td>Duration</td> 
<td>Flow</td> 
<td>%B</td> 
</tr>
<xsl:apply-templates select="methodgradient">
<xsl:sort select="order" data-type="number"/> 
</xsl:apply-templates>

</table>
</td>
</tr>
</xsl:template>
<xsl:template match="methodgradient">
<tr>
<td>
<xsl:value-of select="time" /> 
</td>
<td>
<xsl:value-of select="duration" /> 
</td>
<td>
<xsl:value-of select="flow" /> 
</td>
<td>
<xsl:value-of select="percentB" /> 
</td>
</tr>
</xsl:template>
<xsl:template match="samples">
<hr /> 
<h3>Samples</h3> 
<table border="1">
<tr>
<td>Method ID</td> 
<td>Method name</td> 
<td>Sample name</td> 
<td>Position</td> 
<td>Injections</td> 
</tr>
<xsl:apply-templates select="batchsample" /> 
</table>
</xsl:template>
<xsl:template match="batchsample">
<tr>
<td>
<xsl:value-of select="methodId" /> 
</td>
<td>
<xsl:value-of select="methodName" /> 
</td>
<td>
<xsl:value-of select="sampleName" /> 
</td>
<td>

<xsl:apply-templates select="position/positionId" />
<xsl:value-of select="position/row" />, <xsl:value-of select="position/column" /> 
</td>
<td>
<xsl:value-of select="injections" /> 
</td>
</tr>
</xsl:template>

<xsl:template match="position/positionId">
<xsl:value-of select="." />
<xsl:text>-</xsl:text>
</xsl:template>

</xsl:stylesheet>